==> libnjb_1.1.orig.tar.gz: libnjb-1.1/sample/sendtr.c <==
#include <sys/types.h>
#include <sys/stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <limits.h>
#include <unistd.h>
#include <libnjb.h>

char *prompt (const char *prompt, char *buffer, size_t bufsz, int required);
int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data);
void usage(void);

int main(int argc, char **argv)
{
	njb_t njbs[NJB_MAX_DEVICES], *njb;
	int n, opt, debug;
	extern int optind;
	extern char *optarg;
	char *path, artist[80], title[80], genre[80], codec[80], album[80];
	char num[80];
	char *partist, *ptitle, *pgenre, *pcodec, *palbum, *pnum;
	u_int32_t tracknum, length, size;
	struct stat sb;
	int trackid;
	char *lang;

	debug= 0;
	while ( (opt= getopt(argc, argv, "D:")) != -1 ) {
		switch (opt) {
		case 'D':
			debug= atoi(optarg);
			break;
		default:
			usage();
		}
	}
	argc-= optind;
	argv+= optind;

	if ( argc != 1 ) usage();
	if ( debug ) NJB_Set_Debug(debug);

	/*
	 * Check environment variables $LANG and $LC_CTYPE
	 * to see if we want to support UTF-8 unicode
	 * $LANG = "xx_XX.UTF-8" or $LC_CTYPE = "?"
	 * trigger unicode support.
	 */
	lang = getenv("LANG");
	if (lang != NULL) {
	  if (strlen(lang) > 5) {
	    if (!strcmp(&lang[strlen(lang)-5], "UTF-8")) {
	       NJB_Set_Unicode(NJB_UC_UTF8);
	    }
	  }
	}

	path= argv[0];

	if ( stat(path, &sb) == -1 ) {
		fprintf(stderr, "%s: ", path);
		perror("stat");
		return 1;
	}
	size= (u_int32_t) sb.st_size;

	if ( (pcodec= prompt("Codec", codec, 80, 1)) == NULL ) return 1;

	if ( (ptitle= prompt("Title", title, 80, 0)) == NULL ) return 1;
	if ( ! strlen(ptitle) ) ptitle= NULL;

	if ( (palbum= prompt("Album", album, 80, 0)) == NULL ) return 1;
	if ( ! strlen(palbum) ) palbum= NULL;

	if ( (partist= prompt("Artist", artist, 80, 0)) == NULL ) return 1;
	if ( ! strlen(partist) ) partist= NULL;

	if ( (pgenre= prompt("Genre", genre, 80, 0)) == NULL ) return 1;
	if ( ! strlen(pgenre) ) pgenre= NULL;

	if ( (pnum= prompt("Track number", num, 80, 0)) == NULL ) return 1;
	if ( strlen(pnum) ) {
		tracknum= strtoul(pnum, 0, 10);
	} else {
		tracknum= 0;
	}

	if ( (pnum= prompt("Length", num, 80, 0)) == NULL ) return 1;
	if ( strlen(pnum) ) {
		length= strtoul(pnum, 0, 10);
	} else {
		length= 0;
	}

	printf("Sending track:\n");
	printf("Codec:     %s\n", pcodec);
	if (ptitle) printf("Title:     %s\n", ptitle);
	if (palbum) printf("Album:     %s\n", palbum);
	if (partist) printf("Artist:    %s\n", partist);
	if (pgenre) printf("Genre:     %s\n", pgenre);

	if ( NJB_Discover(njbs, 0, &n) == -1 ) {
		njb_error_dump(stderr);
		return 1;
	}
	if ( n == 0 ) {
		fprintf(stderr, "no NJB devices found\n");
		return 0;
	} 

	njb= njbs;

	if ( NJB_Open(njb) == -1 ) {
		njb_error_dump(stderr);
		return 1;
	}

	NJB_Capture(njb);

	if ( NJB_Send_Track(njb, path, pcodec, ptitle, palbum, pgenre,
		partist, length, tracknum, NULL, 0, progress, NULL, &trackid) == -1 ) {
		printf("\n");
		njb_error_dump(stderr);
	} else {
		printf("\nNJB ID:    %u\n", trackid);
	}
	printf("\n");

	NJB_Release(njb);
	NJB_Close(njb);

	return 0;
}

int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data)
{
	int percent = (sent*100)/total;
	printf("Progress: %qu of %qu (%d%%)\r", sent, total, percent);
	fflush(stdout);
	return 0;
}

char *prompt (const char *prompt, char *buffer, size_t bufsz, int required)
{
	char *cp, *bp;

	while (1) {
		fprintf(stdout, "%s> ", prompt);
		if ( fgets(buffer, bufsz, stdin) == NULL ) {
			if (ferror(stdin)) {
				perror("fgets");
			} else {
				fprintf(stderr, "EOF on stdin\n");
			}
			return NULL;
		}

		cp= strrchr(buffer, '\n');
		if ( cp != NULL ) *cp= '\0';

		bp= buffer;
		while ( bp != cp ) {
			if ( *bp != ' ' && *bp != '\t' ) return bp;
			bp++;
		}

		if (! required) return bp;
	}
}

void usage (void)
{
	fprintf(stderr, "usage: sendtr [ -D debuglvl ] <path>\n");
	exit(1);
}

==> libnjb_1.2.orig.tar.gz: libnjb-1.2/sample/sendtr.c <==
#include <string.h>
#include <sys/stat.h>
#include <libnjb.h>
#include <getopt.h>

char *prompt (const char *prompt, char *buffer, size_t bufsz, int required);
int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data);
void usage(void);

int main(int argc, char **argv)
{
	njb_t njbs[NJB_MAX_DEVICES], *njb;
	int n, opt, debug;
	extern int optind;
	extern char *optarg;
	char *path, artist[80], title[80], genre[80], codec[80], album[80];
	char num[80];
	char *partist, *ptitle, *pgenre, *pcodec, *palbum, *pnum;
	u_int32_t tracknum, length, size;
	struct stat sb;
	int trackid;
	char *lang;

	debug= 0;
	while ( (opt= getopt(argc, argv, "D:")) != -1 ) {
		switch (opt) {
		case 'D':
			debug= atoi(optarg);
			break;
		default:
			usage();
		}
	}
	argc-= optind;
	argv+= optind;

	if ( argc != 1 ) usage();
	if ( debug ) NJB_Set_Debug(debug);

	/*
	 * Check environment variables $LANG and $LC_CTYPE
	 * to see if we want to support UTF-8 unicode
	 * $LANG = "xx_XX.UTF-8" or $LC_CTYPE = "?"
	 * trigger unicode support.
	 */
	lang = getenv("LANG");
	if (lang != NULL) {
	  if (strlen(lang) > 5) {
	    if (!strcmp(&lang[strlen(lang)-5], "UTF-8")) {
	       NJB_Set_Unicode(NJB_UC_UTF8);
	    }
	  }
	}

	path= argv[0];

	if ( stat(path, &sb) == -1 ) {
		fprintf(stderr, "%s: ", path);
		perror("stat");
		return 1;
	}
	size= (u_int32_t) sb.st_size;

	if ( (pcodec= prompt("Codec", codec, 80, 1)) == NULL ) return 1;

	if ( (ptitle= prompt("Title", title, 80, 0)) == NULL ) return 1;
	if ( ! strlen(ptitle) ) ptitle= NULL;

	if ( (palbum= prompt("Album", album, 80, 0)) == NULL ) return 1;
	if ( ! strlen(palbum) ) palbum= NULL;

	if ( (partist= prompt("Artist", artist, 80, 0)) == NULL ) return 1;
	if ( ! strlen(partist) ) partist= NULL;

	if ( (pgenre= prompt("Genre", genre, 80, 0)) == NULL ) return 1;
	if ( ! strlen(pgenre) ) pgenre= NULL;

	if ( (pnum= prompt("Track number", num, 80, 0)) == NULL ) return 1;
	if ( strlen(pnum) ) {
		tracknum= strtoul(pnum, 0, 10);
	} else {
		tracknum= 0;
	}

	if ( (pnum= prompt("Length", num, 80, 0)) == NULL ) return 1;
	if ( strlen(pnum) ) {
		length= strtoul(pnum, 0, 10);
	} else {
		length= 0;
	}

	printf("Sending track:\n");
	printf("Codec:     %s\n", pcodec);
	if (ptitle) printf("Title:     %s\n", ptitle);
	if (palbum) printf("Album:     %s\n", palbum);
	if (partist) printf("Artist:    %s\n", partist);
	if (pgenre) printf("Genre:     %s\n", pgenre);

	if ( NJB_Discover(njbs, 0, &n) == -1 ) {
		njb_error_dump(stderr);
		return 1;
	}
	if ( n == 0 ) {
		fprintf(stderr, "no NJB devices found\n");
		return 0;
	} 

	njb= njbs;

	if ( NJB_Open(njb) == -1 ) {
		njb_error_dump(stderr);
		return 1;
	}

	NJB_Capture(njb);

	if ( NJB_Send_Track(njb, path, pcodec, ptitle, palbum, pgenre,
		partist, length, tracknum, NULL, 0, progress, NULL, &trackid) == -1 ) {
		printf("\n");
		njb_error_dump(stderr);
	} else {
		printf("\nNJB ID:    %u\n", trackid);
	}
	printf("\n");

	NJB_Release(njb);
	NJB_Close(njb);

	return 0;
}

int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data)
{
	int percent = (sent*100)/total;
#ifdef __WIN32__
	printf("Progress: %I64u of %I64u (%d%%)\r", sent, total, percent);
#else
	printf("Progress: %llu of %llu (%d%%)\r", sent, total, percent);
#endif
	fflush(stdout);
	return 0;
}

char *prompt (const char *prompt, char *buffer, size_t bufsz, int required)
{
	char *cp, *bp;

	while (1) {
		fprintf(stdout, "%s> ", prompt);
		if ( fgets(buffer, bufsz, stdin) == NULL ) {
			if (ferror(stdin)) {
				perror("fgets");
			} else {
				fprintf(stderr, "EOF on stdin\n");
			}
			return NULL;
		}

		cp= strrchr(buffer, '\n');
		if ( cp != NULL ) *cp= '\0';

		bp= buffer;
		while ( bp != cp ) {
			if ( *bp != ' ' && *bp != '\t' ) return bp;
			bp++;
		}

		if (! required) return bp;
	}
}

void usage (void)
{
	fprintf(stderr, "usage: sendtr [ -D debuglvl ] <path>\n");
	exit(1);
}
